==> kubernetes-model-core-4.12.0-sources.jar: io/fabric8/kubernetes/api/model/ServiceListFluent.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.StringBuffer;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface ServiceListFluent<A extends ServiceListFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,Service item);
    public A setToItems(int index,Service item);
    public A addToItems(Service... items);
    public A addAllToItems(Collection<Service> items);
    public A removeFromItems(Service... items);
    public A removeAllFromItems(Collection<Service> items);
    public A removeMatchingFromItems(io.fabric8.kubernetes.api.builder.Predicate<ServiceBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<Service> getItems();
    public List<Service> buildItems();
    public Service buildItem(int index);
    public Service buildFirstItem();
    public Service buildLastItem();
    public Service buildMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<ServiceBuilder> predicate);
    public Boolean hasMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<ServiceBuilder> predicate);
    public A withItems(List<Service> items);
    public A withItems(Service... items);
    public Boolean hasItems();
    public ServiceListFluent.ItemsNested<A> addNewItem();
    public ServiceListFluent.ItemsNested<A> addNewItemLike(Service item);
    public ServiceListFluent.ItemsNested<A> setNewItemLike(int index,Service item);
    public ServiceListFluent.ItemsNested<A> editItem(int index);
    public ServiceListFluent.ItemsNested<A> editFirstItem();
    public ServiceListFluent.ItemsNested<A> editLastItem();
    public ServiceListFluent.ItemsNested<A> editMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<ServiceBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ListMeta getMetadata();
    public ListMeta buildMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
    public ServiceListFluent.MetadataNested<A> withNewMetadata();
    public ServiceListFluent.MetadataNested<A> withNewMetadataLike(ListMeta item);
    public ServiceListFluent.MetadataNested<A> editMetadata();
    public ServiceListFluent.MetadataNested<A> editOrNewMetadata();
    public ServiceListFluent.MetadataNested<A> editOrNewMetadataLike(ListMeta item);
    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ServiceFluent<ServiceListFluent.ItemsNested<N>> {

        public N and();
        public N endItem();    }


    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ListMetaFluent<ServiceListFluent.MetadataNested<N>> {

        public N and();
        public N endMetadata();    }


}

==> kubernetes-model-core-5.0.3-sources.jar: io/fabric8/kubernetes/api/model/ServiceListFluent.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.StringBuffer;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface ServiceListFluent<A extends ServiceListFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,Service item);
    public A setToItems(int index,Service item);
    public A addToItems(Service... items);
    public A addAllToItems(Collection<Service> items);
    public A removeFromItems(Service... items);
    public A removeAllFromItems(Collection<Service> items);
    public A removeMatchingFromItems(Predicate<ServiceBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<Service> getItems();
    public List<Service> buildItems();
    public Service buildItem(int index);
    public Service buildFirstItem();
    public Service buildLastItem();
    public Service buildMatchingItem(Predicate<ServiceBuilder> predicate);
    public Boolean hasMatchingItem(Predicate<ServiceBuilder> predicate);
    public A withItems(List<Service> items);
    public A withItems(Service... items);
    public Boolean hasItems();
    public ServiceListFluent.ItemsNested<A> addNewItem();
    public ServiceListFluent.ItemsNested<A> addNewItemLike(Service item);
    public ServiceListFluent.ItemsNested<A> setNewItemLike(int index,Service item);
    public ServiceListFluent.ItemsNested<A> editItem(int index);
    public ServiceListFluent.ItemsNested<A> editFirstItem();
    public ServiceListFluent.ItemsNested<A> editLastItem();
    public ServiceListFluent.ItemsNested<A> editMatchingItem(Predicate<ServiceBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ListMeta getMetadata();
    public ListMeta buildMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
    public ServiceListFluent.MetadataNested<A> withNewMetadata();
    public ServiceListFluent.MetadataNested<A> withNewMetadataLike(ListMeta item);
    public ServiceListFluent.MetadataNested<A> editMetadata();
    public ServiceListFluent.MetadataNested<A> editOrNewMetadata();
    public ServiceListFluent.MetadataNested<A> editOrNewMetadataLike(ListMeta item);
    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ServiceFluent<ServiceListFluent.ItemsNested<N>> {

            public N and();
            public N endItem();    }


    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ListMetaFluent<ServiceListFluent.MetadataNested<N>> {

            public N and();
            public N endMetadata();    }


}
